<?php
/**
 * Add the about page under appearance.
 *
 * Display the details about the theme information
 *
 * @package Snapfolio
 */
?>
<?php
// About Information
add_action( 'admin_menu', 'snapfolio_about' );
function snapfolio_about() {         
        add_theme_page( esc_html__('About Theme', 'snapfolio'), esc_html__('Snapfolio Theme', 'snapfolio'), 'edit_theme_options', 'snapfolio-about', 'snapfolio_about_page');   
}

// CSS for About Theme Page
function snapfolio_admin_theme_style($hook) {

        if ( 'appearance_page_snapfolio-about' != $hook ) {
        return;
    }

   wp_enqueue_style('snapfolio-admin-style', get_template_directory_uri() . '/inc/admin/theme-info.css');
}
add_action('admin_enqueue_scripts', 'snapfolio_admin_theme_style');

function snapfolio_about_page() {
$theme = wp_get_theme();
$pro_purchase_url = "https://themecanary.com/pricing/snapfolio/";
$doc_url = "https://themecanary.com/documentation/snapfolio/";
$demo_url = "https://themecanary.com/themes/snapfolio/#demos";
$support_url = "https://wordpress.org/support/theme/snapfolio/";

$theme_name = esc_html( $theme->Name );
$free_theme_name = str_replace( ' Pro', '',$theme_name );
$plugin_is_installed = file_exists( WP_PLUGIN_DIR. '/one-click-demo-import' );
$plugin_is_active = is_plugin_active( 'one-click-demo-import/one-click-demo-import.php' );
?>
<div class="snapfolio-wrapper">
  <div id="theme-info-page">
    <div class="admin-banner">
      <div class="banner-left">
        <h2>
          <?php echo esc_html( $theme->Name ); ?>
        </h2>
        <p>
          <?php esc_html_e( 'Bring your story to life with stunning photos using Snapfolio WordPress Theme', 'snapfolio' ); ?>
        </p>
      </div>
      <div class="banner-right">
        <div class="snapfolio-buttons">
          <a href="<?php echo esc_url($doc_url); ?>" class="snapfolio-admin-button demo" target="_blank" rel="noreferrer">
            <?php esc_html_e( 'Documentation', 'snapfolio' ); ?>
          </a>
          <a href="<?php echo esc_url($demo_url); ?>" class="snapfolio-admin-button documentation" target="_blank" rel="noreferrer">
            <?php esc_html_e( 'Demo', 'snapfolio' ); ?>
          </a>
          <a href="<?php echo esc_url($pro_purchase_url); ?>" class="snapfolio-admin-button upgrade-to-pro" target="__blank">
            <?php echo esc_html( 'Upgrade Pro', 'snapfolio' ); ?>
          </a>
        </div>
      </div>
    </div>

    <div class="theme-canary-demo-import">
      <h2><?php esc_html_e( 'Download Demo content for Free!', 'snapfolio' ); ?></h2>
      <p><?php esc_html_e( 'Install Recommended Plugins and access to all the Theme Canary Demo templates. This plugin will help you to show exactly as shown in demo', 'snapfolio' ); ?></p>
        <?php if ( ! $plugin_is_installed  ): ?>
        <a href="javascript:void(0);"  class="snapfolio-admin-button snapfolio-install-plugin" >
          <span class="dashicons dashicons-arrow-down-alt"></span>
            <?php printf( esc_html( 'Install Plugin', 'snapfolio' ), $theme->Name ); ?>
        </a>
        <?php elseif ( $plugin_is_installed && ! $plugin_is_active ): ?>
        <a href="javascript:void(0);"  class="snapfolio-admin-button snapfolio-activate-plugin" >
          <span class="dashicons dashicons-arrow-down-alt"></span>
            <?php printf( esc_html( 'Activate Plugin', 'snapfolio' ), $theme->Name ); ?>
        </a>
        <?php else:?>
        <a href="<?php echo esc_url( admin_url( 'themes.php?page=one-click-demo-import' ) ); ?>"  class="snapfolio-admin-button" >
          <span class="dashicons dashicons-arrow-down-alt"></span>
            <?php printf( esc_html( 'Explore Templates', 'snapfolio' ), $theme->Name ); ?>
        </a>
        <?php endif; ?>
          <small><?php esc_html_e( 'Note: Clicking the button will both install and activate recommended plugins. It may take few minutes to install all the plugins', 'snapfolio' ); ?></small>
    </div>
    <div class="feature-list">
          <div class="snapfolio-about-container compare-table">
              <h3>
                <?php echo esc_html( $free_theme_name ); ?>
                <?php esc_html_e( 'Free Vs Pro', 'snapfolio' ); ?>
              </h3>
              <table>
                <thead>
                   <tr>
                    <th>
                      <?php esc_html_e( 'Features', 'snapfolio' ); ?>
                    </th>
                    <th>
                     <?php esc_html_e( 'Snapfolio Free', 'snapfolio' ); ?>
                    </th>
                    <th>
                      <?php esc_html_e( 'Snapfolio Pro', 'snapfolio' ); ?>
                    </th>
                  </tr>
                </thead>
                <tbody>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Easy Setup', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Responsive', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Color Skin', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Background Color Options', 'snapfolio' ); ?>
                    </td>
                    <td><?php esc_html_e( 'Change body Background only', 'snapfolio' ); ?></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                   <tr>
                    <td>
                      <?php esc_html_e( 'Font Color Options', 'snapfolio' ); ?>
                    </td>
                    <td><?php esc_html_e( 'Change Banner Text', 'snapfolio' ); ?></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Font Family', 'snapfolio' ); ?>
                    </td>
                    <td> <?php esc_html_e( '1 Google Fonts', 'snapfolio' ); ?>
                    </td>
                    <td><?php esc_html_e( '800+ Google Fonts', 'snapfolio' ); ?>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Slider ', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Multiple Footer Column', 'snapfolio' ); ?>
                    </td>
                    <td><?php esc_html_e( '3 Column', 'snapfolio' ); ?></span>
                    </td>
                    <td><?php esc_html_e( '1/2/3/4 Column', 'snapfolio' ); ?></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Footer Editing Options', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Font Size', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Change Excerpt & Search Text', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Front/ Home page posts categories', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Sticky Menu', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Blog/ Single Options', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Change Header Content', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Boxed Layout', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Site Layout', 'snapfolio' ); ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Footer Menu','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Instagram Feed','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Wooommerce Compatible','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'bbPress Compatible','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Disable Header Section','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Video Banner','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Display posts Orders','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                  <tr>
                    <td>
                      <?php esc_html_e( 'Display posts Types','snapfolio') ?>
                    </td>
                    <td><span class="dashicons dashicons-no"></span>
                    </td>
                    <td><span class="dashicons dashicons-yes"></span>
                    </td>
                  </tr>
                </tbody>
              </table>
          </div>
      <div class="about-us">
        <div class="our-product"><span><i class="fa fa-star" aria-hidden="true"></i> <i class="fa fa-star" aria-hidden="true"></i> <i class="fa fa-star" aria-hidden="true"></i> <i class="fa fa-star" aria-hidden="true"></i> <i class="fa fa-star" aria-hidden="true"></i></span>
          <h3>
            <?php esc_html_e( 'Love our product?', 'snapfolio' ); ?>
          </h3>
          <h4>
            <?php esc_html_e( 'Motivate 5 Star rating', 'snapfolio' ); ?>
          </h4>
          <a href="https://wordpress.org/support/theme/snapfolio/reviews/?filter=5" class="snapfolio-admin-button" target="__blank">
            <?php esc_html_e( 'Rate Us', 'snapfolio' ); ?>
          </a>
        </div>
        <div class="our-product">
          <h3>
            <?php esc_html_e( 'Still have any question?', 'snapfolio' ); ?>
          </h3>
          <p>
          <?php esc_html_e( 'Don\'t hesitate to ask', 'snapfolio' ); ?>
          </p>
          <a href="<?php echo esc_url($support_url); ?>" class="snapfolio-admin-button" target="_blank">
            <?php esc_html_e( 'Get Support', 'snapfolio' ); ?>
          </a>
        </div>
        <div class="snapfolio-buttons">
          <a href="<?php echo esc_url($pro_purchase_url); ?>" class="snapfolio-admin-button upgrade-to-pro" rel="noreferrer" target="_blank"><i class="fa fa-paint-brush"></i>
            <?php printf( esc_html( 'Get Snapfolio Pro', 'snapfolio' ), $theme->Name ); ?>
          </a>
          <a href="<?php echo esc_url($doc_url); ?>" class="snapfolio-admin-button premium-button documentation" target="_blank" rel="noreferrer"><i class="fa fa-book"></i>
            <?php esc_html_e( 'Documentation', 'snapfolio' ); ?>
          </a>
        </div>
      </div>
    </div>
</div>

<?php }