<?php
/**
 * Custom functions
 *
 * @package Snapfolio
 * @subpackage Snapfolio
 * @since Snapfolio 1.0
 */

 /**
 * Social Icons
 */
function snapfolio_social_icon() {
	if ( has_nav_menu( 'menu-3' ) ) : ?>
		<div class="social-icons clear">
			<?php
				wp_nav_menu( array(
					'container' 	=> '',
					'theme_location' => 'menu-3',
					'depth'          => 1,
					'items_wrap'      => '<ul>%3$s</ul>',
					'link_before'    => '<span class="screen-reader-text">',
					'link_after'     => '</span>',
					'link_after'     => '</span>' . snapfolio_get_icons(array( 'icon' => 'default-link' ) ),
				) );
			?>
		</div><!-- end .social-links -->
	<?php endif; ?>
<?php }
add_action ('snapfolio_social_icon_show', 'snapfolio_social_icon');

/* Adding Fonts */
	
if ( ! function_exists( 'snapfolio_fonts_url' ) ) :
	/**
	 * Register Google fonts for Snapfolio.
	 *
	 * Create your own snapfolio_fonts_url() function
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function snapfolio_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
	
		/* translators: If there are characters in your language that are not supported by Roboto+Slab, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Roboto Slab font: on or off', 'snapfolio' ) ) {
			$fonts[] = 'Roboto Slab:wght@100;200;300;400;500;800';
		}
	
		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => implode('&family=', $fonts) ,
				'display' => 'swap',
			), 'https://fonts.googleapis.com/css2' );
		}
	
		return esc_url_raw($fonts_url);
	}
	endif;

/**
 * Enqueue scripts and styles.
 */
	function snapfolio_scripts() {
		$disable_sticky_menu = get_theme_mod ('disable_sticky_menu', 0);
		$display_original_logo = get_theme_mod('display_original_logo','default');
		$disable_featured_image_single = get_theme_mod('disable-featured-image-single', 0);

		require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );
		wp_enqueue_style( 'snapfolio-google-fonts', wptt_get_webfont_url(snapfolio_fonts_url()), array(), null );
		wp_enqueue_style( 'snapfolio-style', get_stylesheet_uri(), array(), Snapfolio_Version );

		if (empty($disable_sticky_menu)){
			wp_enqueue_script('jquery-sticky', get_template_directory_uri().'/assets/sticky/jquery.sticky.js', array('jquery'), false, true);
			wp_enqueue_script('snapfolio-sticky-settings', get_template_directory_uri().'/assets/sticky/sticky-settings.js', array('jquery'), false, true);
		}
		wp_enqueue_style('animate-css', get_template_directory_uri().'/assets/wow/css/animate.min.css');
		wp_enqueue_script('wow', get_template_directory_uri().'/assets/wow/js/wow.min.js', array('jquery'), false, true);
		wp_enqueue_script('snapfolio-wow-settings', get_template_directory_uri().'/assets/wow/js/wow-settings.js', array('jquery'), false, true);
		wp_enqueue_style('snapfolio-isotope', get_template_directory_uri().'/css/isotope.css');
		wp_enqueue_script('imagesloaded-pkgd', get_template_directory_uri().'/js/imagesloaded.pkgd.min.js', array('jquery'), false, true);
		wp_enqueue_script('isotope', get_template_directory_uri().'/js/isotope.pkgd.min.js', array('jquery'), false, true);
		wp_enqueue_script('snapfolio-isotope-setting', get_template_directory_uri().'/js/isotope-setting.js', array('isotope'), false, true);
		wp_enqueue_script('snapfolio-custom', get_template_directory_uri().'/js/custom.js', array('jquery'), false, true);
		// Load the html5 shiv.
		wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
		wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
		wp_enqueue_script( 'snapfolio-navigation', get_template_directory_uri() . '/js/navigation.js', array(), Snapfolio_Version, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_enqueue_script('snapfolio-skip-link-focus-fix', get_template_directory_uri().'/js/skip-link-focus-fix.js', array('jquery'), false, true);
		wp_enqueue_style('snapfolio-iconstyle', get_template_directory_uri().'/assets/font-icons/css/all.min.css');
		wp_enqueue_script('snapfolio-navigation', get_template_directory_uri().'/js/navigation.js', array('jquery'), false, true);

		/* Custom Css */
		$snapfolio_inline_css='';

		if ($display_original_logo == 'original'){
			$snapfolio_inline_css .= '
				.custom-logo {
				    height: auto;
				}
			';
		}

		if (!empty($disable_featured_image_single)){
			$snapfolio_inline_css .= '.single .post-featured-image {
				display:none;
			}';

		}

		if (!empty($disable_sticky_menu)){
			$snapfolio_inline_css .= '.main-header #site-branding {
				display:none;
			}';

		}

		

		wp_add_inline_style( 'snapfolio-style', wp_strip_all_tags($snapfolio_inline_css) );

	}
	add_action( 'wp_enqueue_scripts', 'snapfolio_scripts', 100 );

	/************** Enqueue editor styles for Gutenberg *************************************/
	function snapfolio_block_editor_styles() {
		// Block styles.
		wp_enqueue_style( 'snapfolio-block-editor-style', get_theme_file_uri() . '/css/editor-blocks.css' );
	
		// Add custom fonts.
		wp_enqueue_style( 'snapfolio-google-fonts', snapfolio_fonts_url(), array(), null );
	}
	add_action( 'enqueue_block_editor_assets', 'snapfolio_block_editor_styles' );

	// Header banner text color
	function snapfolio_banner_text() { 
		$banner_text_color = get_theme_mod('header-banner-text-color','#ffffff');


		if( $banner_text_color == '#ffffff' ){
			return;
		}
		$snapfolio_inline_css='
		/* Header Banner Text */
		
		.section-title {
			color: %1$s;

		}
		ul.custom-header-content-search-tags li, ul.custom-header-content-search-tags li a {
			color: %1$s;
		} ';

		wp_add_inline_style( 'snapfolio-style', sprintf( $snapfolio_inline_css,
		$banner_text_color
		) );

	}
	add_action( 'wp_enqueue_scripts', 'snapfolio_banner_text', 110 );

	// Default Theme color
	function snapfolio_theme_color() { 
		$default_theme_color = get_theme_mod('default-theme-color','#ed1c24');


		if( $default_theme_color == '#ed1c24' ){
			return;
		}
		$snapfolio_theme_color='
		/* Theme Color */

		.back-to-top,
		button,
		input[type="reset"],
		input[type="button"],
		input[type="submit"],
		.search-submit,
		.widget-title, .widget_block h2,
		.widget_calendar #wp-calendar caption,
		.bbp-submit-wrapper button.submit,
		.woocommerce #respond input#submit, 
		.woocommerce a.button, 
		.woocommerce button.button, 
		.woocommerce input.button,
		.woocommerce #respond input#submit.alt, 
		.woocommerce a.button.alt, 
		.woocommerce button.button.alt, 
		.woocommerce input.button.alt,
		.woocommerce-demo-store p.demo_store,
		.more-button:hover,
		.post-image-content .posted-on:before,
		.wp-block-file .wp-block-file__button,
  		.wp-block-search .wp-block-search__button,
  		.wp-block-button .wp-block-button__link,
  		.social-icons li a:hover
		 {
			background-color: %1$s;
		}

		.bbp-submit-wrapper button.submit,
		.is-style-outline .wp-block-button__link,
		.is-style-outline .more-link,
		.is-style-outline .button,
		.is-style-outline .wp-block-button__link,
		.is-style-outline .more-link,
		.is-style-outline .button   {
			border: 1px solid %1$s;
		}

		.wp-block-pullquote,
		.wp-block-pullquote.alignleft,
		.wp-block-pullquote.alignright,
		.wp-block-quote.is-large,
		.wp-block-quote.is-style-large,
		.wp-block-quote {
		  border-color:  %1$s;
		}

		::selection, ::-moz-selection {
			background:%1$s;
		
		}

		a:hover,a:focus, a.more-link, 
		.screen-reader-text:focus,
		.entry-content a:hover,
		.widget ul li a:hover,
		.widget ul li a:focus,
		.widget_tag_cloud a,
		.breadcrumb a:hover,
		#bbpress-forums .bbp-topics a:hover,
		.woocommerce .woocommerce-message:before,
		.info-bar .info-menu a:hover,
		.info-bar .info-menu a:focus,
		.entry-title a:hover,
		.entry-title a:focus,
		h2.featured-title a:focus,
		h2.featured-title:focus,
		.entry-title a:active,
		.entry-meta a:hover, 
		.posted-on time.entry-date.published.updated:hover, 
		.byline:hover,
		.tags-links:hover,
		h2.featured-title a:hover,
		h2.featured-title:hover,
		.byline:hover,
		.tags-links:hover,
		.widget ol li a:hover,
		.widget ul li a:hover,
		.edit-link a:hover,
		.byline:focus,
		.tags-links:focus,
		.widget ol li a:focus,
		.widget ul li a:focus,
		.edit-link a:focus,
		.navigation.post-navigation .nav-previous::before,
		.navigation.post-navigation .nav-next::after,
		#colophon .widget ul li a:hover,
		#colophon .widget ul li a:focus,
		.site-info .copyright a:hover,
		.site-info .copyright a:focus,
		.main-navigation ul li.current-menu-item a,
		.main-navigation ul li.current_page_item a,
		.main-navigation ul li:hover > a,
		.main-navigation li.current-menu-item.menu-item-has-children > a:after,
		.main-navigation ul li:hover > a:after,
		.main-navigation li.menu-item-has-children > a:hover:after,
		.main-navigation li.page_item_has_children > a:hover:after,
		.main-navigation ul li.current-menu-ancestor a
		  {
			color: %1$s;
		}
		@media only screen and (max-width: 980px) { 

			.menu-container {
			  background-color: %1$s;

			}

		}';

		wp_add_inline_style( 'snapfolio-style', sprintf( $snapfolio_theme_color,
		$default_theme_color
		) );

	}
	add_action( 'wp_enqueue_scripts', 'snapfolio_theme_color', 120 );

/**
 * Site Branding
 */
function snapfolio_site_branding(){ ?>
   <div id="site-branding">
        <?php the_custom_logo(); ?>
        <div id="site-detail">
            <?php if ( is_front_page() && is_home() ) : ?>
                <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                <?php
            else :
                ?>
                <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                <?php
            endif;
            $snapfolio_description = get_bloginfo( 'description', 'display' );
            if ( $snapfolio_description || is_customize_preview() ) :
                ?>
                <div class="site-description"><?php echo $snapfolio_description; ?></div>
            <?php endif; ?>

        </div><!-- end . site-detail -->
    </div><!-- .site-branding -->
	<?php
 }

add_action('snapfolio_site_branding_show','snapfolio_site_branding');

/**
 * Search Form
 */
function snapfolio_search_form(){ ?>
	<form  method="get" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>"> 
		<label class='screen-reader-text'><?php esc_html_e( 'Search', 'snapfolio' ); ?></label> 
		<input class="search-field" placeholder="<?php echo esc_attr_x( 'Search Images &hellip;', 'placeholder', 'snapfolio' ); ?>" name="s" type="search"> 
		<button type="submit" class="search-submit">
			<i class="fas fa-search"></i>
		</button>
	</form>
    
<?php }
add_action('snapfolio_search_form_show','snapfolio_search_form');

/**
 * Breadcrumb
 */

function snapfolio_breadcrumb() {
	if (function_exists('bcn_display')) { ?>
		<div class="breadcrumb home">
			<?php bcn_display(); ?>
		</div> <!-- .breadcrumb -->
	<?php }
}

add_action('snapfolio_breadcrumb_show','snapfolio_breadcrumb');

/**
 * Header Image and Content
 */


function snapfolio_header_image_content() { 
	$disable_tags = get_theme_mod ('disable-tags',0);
	$disable_header_social_icons = get_theme_mod ('disable-header-social-icons',0);
	if (has_nav_menu('menu-2') || (has_nav_menu('menu-3') && $disable_header_social_icons ==0)): ?> 
		<div class="info-bar">
			<div class="wrapper">
				<?php if (has_nav_menu('menu-2'))
							 { ?>
					<nav class="info-menu" role="navigation" aria-label="<?php esc_attr_e('Infobar Menu', 'snapfolio'); ?>">
						<?php
							wp_nav_menu(array(
								'container' => '',
								'theme_location' => 'menu-2',
								'depth' => 3,
								'items_wrap' => '<ul class="info-menu">%3$s</ul>',
							));
						?>
					</nav> <!-- end .info-menu -->
				<?php
						}

				if (has_nav_menu('menu-3') && $disable_header_social_icons ==0): ?>
											<div class="social-display clear">
												<?php
					/* Display Social Icons */
					do_action('snapfolio_social_icon_show');
						?>
											</div> <!-- end .social-display -->
										<?php
				endif; ?>
			</div> <!-- end .wrapper -->
		</div> <!-- end .info-bar -->
	<?php endif; ?>
	<div class="container clearfix">
		<?php

		do_action('snapfolio_site_branding_show'); ?>
	</div> <!-- end .container -->
	<?php $header_text = get_theme_mod ('header_text','');  ?>

		<div class="custom-header-content">
			<?php if ($header_text !==''){ ?>
				<h2 class="section-title"><?php echo esc_html ($header_text);?></h2>
			<?php }

				/**
				 * Search Form
				 */
				do_action('snapfolio_search_form_show');

			if($disable_tags == 0){ ?>

				<ul class="custom-header-content-search-tags">
				    <?php
				    $tags = get_tags();
				    if ( $tags ) : ?>
				    	<li class="search-tags"><?php esc_html_e('Search with Tags:','snapfolio'); ?></li>
				        <?php foreach ( $tags as $tag ) : ?>
				            <li><a href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>" title="<?php echo esc_attr( $tag->name ); ?>"><?php echo esc_html( $tag->name ); ?></a></li>
				        <?php endforeach; ?>
				    <?php endif; ?>
				</ul>


			<?php } ?>
		</div>
<?php }

add_action('snapfolio_header_image_content_show','snapfolio_header_image_content');


