<?php
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0
 * @access public
 */
final class snapfolio_Customize {

	/**
	 * Returns the instance.
	 *
	 */
	public static function snapfolio_get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->snapfolio_setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 */
	private function snapfolio_setup_actions() {

		// Register panels, snapfolio_sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'snapfolio_sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'snapfolio_enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer snapfolio_sections.
	 *
	 */
	public function snapfolio_sections( $manager ) {

		// Load custom snapfolio_sections.
		require get_template_directory() . '/inc/upgrade-pro/section-pro.php';

		// Register custom section types.
		$manager->register_section_type( 'Snapfolio_Customize_Section_Pro' );

		// Register snapfolio_sections.
		$manager->add_section(
			new Snapfolio_Customize_Section_Pro(
				$manager,
				'snapfolio',
				array(
					'title'    => esc_html__( 'Snapfolio', 'snapfolio' ),
					'pro_text' => esc_html__( 'Upgrade To Pro',         'snapfolio' ),
					'pro_url'  => 'https://themecanary.com/themes/snapfolio-pro/',
					'priority' => 1
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function snapfolio_enqueue_control_scripts() {

		wp_enqueue_script( 'snapfolio-customize-controls', trailingslashit( get_template_directory_uri() ) . 'inc/js/customizer-custom-scripts.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'snapfolio-customize-controls', trailingslashit( get_template_directory_uri() ) . 'css/customize-control.css' );
	}
}

// Doing this customizer thang!
snapfolio_Customize::snapfolio_get_instance();
